/*
 * Copyright (C) 2003-2015 FreeIPMI Core Team
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef IPMI_SEL_OEM_LINUX_KERNEL_RECORD_FORMAT_H
#define IPMI_SEL_OEM_LINUX_KERNEL_RECORD_FORMAT_H

#ifdef __cplusplus
extern "C" {
#endif

#define IPMI_SEL_RECORD_TYPE_NON_TIMESTAMPED_OEM_LINUX_KERNEL_PANIC 0xF0

#ifdef __cplusplus
}
#endif

#endif /* IPMI_SEL_OEM_LINUX_KERNEL_RECORD_FORMAT_H */
